Configuring
===========

.. toctree::
   :maxdepth: 1

   configuring_overview.rst
   multiple_configurations.rst
   configuring_array_multiline_structure_rules.rst
   configuring_blank_lines.rst
   configuring_block_comments.rst
   configuring_comment_keywords.rst
   configuring_conditional_multiline_indent_rules.rst
   configuring_consecutive_blank_line_rules.rst
   configuring_disabled_rules.rst
   configuring_identifier_alignment_rules.rst
   configuring_indentation.rst
   configuring_indent_rules.rst
   configuring_keyword_alignment_rules.rst
   configuring_length_rules.rst
   configuring_move_token_rules.rst
   configuring_multiline_assert_rule.rst
   configuring_multiline_constraint_rules.rst
   configuring_multiline_indent_rules.rst
   configuring_number_of_signals_in_signal_declaration.rst
   configuring_optional_items.rst
   configuring_port_map_new_line.rst
   configuring_port_mode_alignment.rst
   configuring_pragmas.rst
   configuring_prefix_and_suffix_rules.rst
   configuring_previous_line_rules.rst
   configuring_procedure_call_statement_rules.rst
   configuring_rule_groups.rst
   configuring_simple_multiline_structure_rules.rst
   configuring_subprogram_specification_statement_rules.rst
   configuring_type_of_instantiations.rst
   configuring_uppercase_and_lowercase_rules.rst
   configuring_use_clause_indenting.rst
   configuring_whitespace_rules.rst
   configuring_whitespace_after_comment_rules.rst
   configuring_vhdl_reserved_words.rst
